$(document).ready(function(){
  $('td.qty input.form-text')
    // save last valid quantity
    .focus(uc_js_cart_save_item_quantity)
    // recalculate cart item price & trigger recalculate of cart subtotal price
    .keyup(uc_js_cart_recalculate_item_price)
    // restore saved quantity number if quantity field left empty
    .blur(uc_js_cart_restore_item_quantity);
  $('div.uc-js-cart-delete-button')
    // Delete selected cart item
    .click(uc_js_cart_item_delete);
  // disable Update button
  $('input#edit-update-1').attr('disabled', 'disabled');
});

// last entered quantity
var uc_js_cart_item_last_quantity = 0;

/**
 * Save last valid quantity value for item to prevent empty field problem
 */
uc_js_cart_save_item_quantity = function(){
  // allow only numericals
  this.value = this.value.replace(/[^0-9]/g, '');
  // save if not null
  if (this.value.length > 0) {
    // get quantity number
    uc_js_cart_item_last_quantity = Number(this.value);
  }
}

/**
 * Restore saved quantity number if quantity field left empty
 */
uc_js_cart_restore_item_quantity = function(){
  // if empty then
  if (this.value.length == 0) {
    // restore last value
    this.value = uc_js_cart_item_last_quantity;
    // initiate recalculate
    $(item_row).find('input.form-text').keyup();
  }
}

/**
 * Recalculate cart item price & trigger recalculate of cart subtotal price
 */
uc_js_cart_recalculate_item_price = function(){
  // allow only numericals
  this.value = this.value.replace(/[^0-9]/g, '');
  // recalculate if not null
  if (this.value.length > 0) {
    // get quantity number
    this.value = Number(this.value);
    // get cart item row
    var item_row = $(this).parents('tr').get(0);
    // save last quantity to restore after UNFILLED field
    uc_js_cart_item_last_quantity = this.value;
    // save positive quantity to restore after item DELETE
    if (this.value > 0) {
      // save quantity
      $(item_row).find('span.uc-js-cart-item-quantity').text(this.value);
    }
    // get initial price of item
    var item_price = $(item_row).find('span.uc-js-cart-item-price').text();
    // calculate total price of item
    var item_total_price = item_price * this.value;
    // write new price
    $(item_row).find('span.uc-price').text(uc_js_cart_format_price(item_total_price));
    // hover row if quantity iz zero
    if (this.value == 0) {
      $(item_row).find('td').fadeTo('slow', 0.5);
      $(item_row).addClass('uc-js-cart-hovered');
    }
    // onhover if quantity is more than zero
    if (this.value > 0 && $(item_row).hasClass('uc-js-cart-hovered')) {
      $(item_row).find('td').fadeTo('slow', 1);
      $(item_row).removeClass('uc-js-cart-hovered');
    }
  }
  // enable
  $('input#edit-update-1').attr('disabled', '');
  // recalculate cart suvtotal price
  uc_js_cart_recalculate_subtotal_price();
}

/**
 * Recalculate cart subtotal price
 */
uc_js_cart_recalculate_subtotal_price = function(){
  var subtotal_price = 0;
  // get each cart item price and add to new subtotal price
  $('td.price > span.uc-price').each(function(){
    subtotal_price = Number(subtotal_price) + uc_js_cart_tidy_price(this.innerText);
  });
  // write new price
  $('td.subtotal span.uc-price').text(uc_js_cart_format_price(subtotal_price));
  // disable order button if cart subtotal price is zero
  $('input#edit-checkout-1').attr('disabled', (subtotal_price == 0) ? 'disabled' : '');
}

/**
 * Format given price using UC settings
 */
uc_js_cart_format_price = function(price){
  // get settings
  var settings = Drupal.settings.uc_js_cart;
  // format
  i = parseInt(price = Math.abs(+price || 0).toFixed(settings.currency_prec)) + "",
  j = (j = i.length) > 3 ? j % 3 : 0;
  var naturals = (j ? i.substr(0, j) + settings.currency_thou : "") + (i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + settings.currency_thou));
  var decimals = settings.currency_prec > 0 ? settings.currency_dec + Math.abs(price - i).toFixed(settings.currency_prec).slice(2) : "";
  return (settings.sign_after_amount = 1)
    ? naturals + decimals + settings.currency_sign
    : settings.currency_sign + naturals + decimals;
}

/**
 * Tidy given price using UC settings
 */
uc_js_cart_tidy_price = function(price){
  // get settings
  var settings = Drupal.settings.uc_js_cart;
  // remove sign from price
  var no_sign = price.replace(settings.currency_sign, '');
  // remove multiple thousand markers
  var thou = eval('/' + settings.currency_thou + '/g');
  var no_thou = no_sign.replace(thou, '');
  // replace decimal markers
  var no_dec =  no_thou.replace(settings.currency_dec, '.');
  return parseFloat(no_dec);
}

/**
 * Delete selected cart item
 */
uc_js_cart_item_delete = function(){
  // get row object of item
  var item_row = $(this).parents('tr').get(0);
  var item_quantity = $(item_row).find('input.form-text');
  // if row is already delete = restore last quantity and unhover row
  if (item_quantity.attr('value') == 0) {
    var quantity = $(item_row).find('span.uc-js-cart-item-quantity').text();
    item_quantity.attr('value', quantity);
  }
  // set zero as quantity to delete
  else {
    item_quantity.attr('value', 0);
  }
  // trigger recalculate
  item_quantity.keyup();
}